@@ -1,6 +1,6 @@
 from __future__ import absolute_import
 try:
-    from py.test import mark as mark_test
+    from py.test import mark as mark_test  # pylint:disable=unused-import
 except ImportError:
     class _Mark:
         def __getattr__(self, name):
